@@ -80,13 +80,14 @@ class Proxy(proxy2.BaseProxy):
         """Post messages to given queue
 
         :param queue_name: The name of target queue to post message to.
-        :param list messages: List of messages body and TTL to post.
+        :param messages: List of messages body and TTL to post.
+        :type messages: :py:class:`list`
 
         :returns: A string includes location of messages successfully posted.
         """
         message = self._get_resource(_message.Message, None,
                                      queue_name=queue_name)
-        return message.post(self.session, messages)
+        return message.post(self._session, messages)
 
     def messages(self, queue_name, **query):
         """Retrieve a generator of messages
